DanmakuController<T> class
Constructors
-
DanmakuController({required ValueChanged<
DanmakuContentItem< addDanmaku, required ValueChanged<T> >DanmakuOption> updateOption, required VoidCallback pause, required VoidCallback resume, required VoidCallback clear, required DanmakuOption getOption(), required bool isRunning(), required Iterable<DanmakuItem< findDanmaku(Offset), required DanmakuItem<T> >T> ? findSingleDanmaku(Offset), required double getViewWidth(), required double getViewHeight(), required List<DanmakuItem< scrollDanmaku, required List<T> >DanmakuItem< staticDanmaku, required List<T> >DanmakuItem< specialDanmaku})T> >
Properties
-
addDanmaku
→ ValueChanged<
DanmakuContentItem< T> > -
final
- clear → VoidCallback
-
final
-
findDanmaku
→ Iterable<
DanmakuItem< Function(Offset)T> > -
final
-
findSingleDanmaku
→ DanmakuItem<
T> ? Function(Offset) -
final
- getOption → DanmakuOption Function()
-
final
- getViewHeight → double Function()
-
final
- getViewWidth → double Function()
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRunning → bool Function()
-
final
- option → DanmakuOption
-
no setter
- pause → VoidCallback
-
final
- resume → VoidCallback
-
final
- running → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scrollDanmaku
→ List<
DanmakuItem< T> > -
final
-
specialDanmaku
→ List<
DanmakuItem< T> > -
final
-
staticDanmaku
→ List<
DanmakuItem< T> > -
final
-
updateOption
→ ValueChanged<
DanmakuOption> -
final
- viewHeight → double
-
no setter
- viewWidth → double
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited